summaryrefslogtreecommitdiff
path: root/source4/selftest
diff options
context:
space:
mode:
Diffstat (limited to 'source4/selftest')
-rwxr-xr-xsource4/selftest/tests.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/source4/selftest/tests.py b/source4/selftest/tests.py
index 4758ebe5155..67e33fc37dc 100755
--- a/source4/selftest/tests.py
+++ b/source4/selftest/tests.py
@@ -659,10 +659,11 @@ planpythontestsuite("none", "samba.tests.samba_tool.visualize")
for env in all_fl_envs:
planpythontestsuite(env + ":local", "samba.tests.samba_tool.fsmo")
# test samba-tool user and computer edit command
for env in all_fl_envs:
env += ":local"
plantestsuite("samba.tests.samba_tool.user_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/user_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
+ plantestsuite("samba.tests.samba_tool.group_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/group_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
plantestsuite("samba.tests.samba_tool.computer_edit", env, [os.path.join(srcdir(), "python/samba/tests/samba_tool/computer_edit.sh"), '$SERVER', '$USERNAME', '$PASSWORD'])
# We run this test against both AD DC implementations because it is
@@ -659,10 +659,11 @@ planpythontestsuite("none", "samba.tests.samba_tool.visualize")
for env in all_fl_envs:
planpythontestsuite(env + ":local", "samba.tests.samba_tool.fsmo")
-# test samba-tool user and computer edit command
+# test samba-tool user, group and computer edit command
for env in all_fl_envs:
env += ":local"